==> vlc-3.0.0-rc8.tar.xz: vlc-3.0.0-rc8/modules/demux/dash/DASHStream.hpp <==
/*
 * DASHStream.hpp
 *****************************************************************************
 * Copyright (C) 2015 - VideoLAN and VLC authors
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/
#ifndef DASHSTREAM_HPP
#define DASHSTREAM_HPP

#include "../adaptive/Streams.hpp"

namespace dash
{
    using namespace adaptive;

    class DASHStream : public AbstractStream
    {
        public:
            DASHStream(demux_t *);

        protected:
            virtual block_t *checkBlock(block_t *, bool); /* impl */
            virtual AbstractDemuxer * createDemux(const StreamFormat &); /* impl */
    };

    class DASHStreamFactory : public AbstractStreamFactory
    {
        public:
            virtual AbstractStream *create(demux_t*, const StreamFormat &,
                                   SegmentTracker *, AbstractConnectionManager *) const;
    };
}

#endif // DASHSTREAM_HPP

==> vlc-3.0.0-20160606.tar.xz: vlc-3.0.0-20160606/modules/demux/dash/DASHStream.hpp <==
/*
 * DASHStream.hpp
 *****************************************************************************
 * Copyright (C) 2015 - VideoLAN and VLC authors
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/
#ifndef DASHSTREAM_HPP
#define DASHSTREAM_HPP

#include "../adaptive/Streams.hpp"

namespace dash
{
    using namespace adaptive;

    class DASHStream : public AbstractStream
    {
        public:
            DASHStream(demux_t *, const StreamFormat &);

        protected:
            virtual block_t *checkBlock(block_t *, bool); /* impl */
            virtual AbstractDemuxer * createDemux(const StreamFormat &); /* impl */
    };

    class DASHStreamFactory : public AbstractStreamFactory
    {
        public:
            virtual AbstractStream *create(demux_t*, const StreamFormat &,
                                   SegmentTracker *, HTTPConnectionManager *) const;
    };
}

#endif // DASHSTREAM_HPP
